
// USE_3D_Printer_RGB_MAX31855.ino

/***************************************************
  This is an example for the Adafruit Thermocouple Sensor w/MAX31855K

  Using Arduino Nano

  Ref: http://jungletronics.blogspot.co.uk/2016/06/12-arduserie-thermocoupler-amplifier.html

  Designed specifically to work with the Adafruit Thermocouple Sensor
  ----> https://www.adafruit.com/products/269

  These displays use SPI to communicate, 3 pins are required to
  interface
  Adafruit invests time and resources providing this open source code,
  please support Adafruit and open-source hardware by purchasing
  products from Adafruit!

  Written by Limor Fried/Ladyada for Adafruit Industries.
  BSD license, all text above must be included in any redistribution
 ****************************************************/



// NOTE: Temperature may be incorrect reading

// Please note that this code and method may not give a true
// temperature measurement

// I take no reasonability for any inaccuracies or any damage caused.I take no reasonability
// for any inaccuracies or any damage caused.

// Using eBay 2M Wire K Type Thermocouple Temperature Measuring Probe Sensor 2 Pcs
// eBay seller : sellerbible
// This is used because the supplied Thermocouple with the is too phyically big o fit under my Heat Bed


// Arduino Nano

//  RGB LED Colours
//  Blue indicates an error with the Thermocouple Temperature Measuring Probe Sensor
//  Less than or equal to 35°C Green. Cool safe
//  More than 35°C Less than or equal to 45°C Yellow. Medium Heat. This is red + some green, not total green
//  More than 45°C Less than or equal to 50°C Red. Solid. Hot Danger do not touch
//  More than 50°C  Less than or equal to 170°C Red. Flashing. Very Hot Danger do not touch
//  More than 170°C  White Flashing  Red + Green + Blue LED : TOO HOT!!!! OVER Temperature ERROR!!!

// I use resistors for the RGB LED as follows :
// 150 Ohm for Red,
// 100 Ohm for Blue and
// 100 Ohm for Green.

// Using a MAX31855 chip 
// Download link https://1drv.ms/u/s!AjFFUc7muc09hDAkb8BbSts0-anN
// 3D Printer RGB LED MAX31855 Heatbed warning light {Video}
// https://youtu.be/uQj48G6qNS4

//////////////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////////////

#include <SPI.h>
#include "Adafruit_MAX31855.h"

// Example creating a thermocouple instance with software SPI on any three
// digital IO pins.
// Set up I used for Temperature sensor MAX31855
int thermistorCS  = 9;            //    CS pin on MAX31855 to D9 on Arduino Nano
int thermistorSO  = 8;            //    SO pin of MAX31855 to D8 on Arduino Nano
int thermistorSCK = 10;           //    SCK pin of MAX31855 to D10 on Arduino Nano

// initialize the Thermocouple
Adafruit_MAX31855 thermocouple(thermistorSCK, thermistorCS, thermistorSO);

/*-----( RGB LED Pins. Declare Constants and Pin Numbers )-----*/
int redPin   =  6;               //   Red LED connected to digital pin PWM D6 on Arduino Nano
int greenPin =  5;               //   Green LED connected to digital pin PWM D5 on Arduino Nano
int bluePin  =  3;               //   Blue LED connected to digital pin PWM D3 on Arduino Nano

//////////////////////////////////////////////////////////////////////////////////////

void setup()   /****** SETUP: RUNS ONCE ******/
{
  Serial.begin(115200);

  Serial.println("MAX31855 wait for MAX chip to stabilize.");
  // wait for MAX chip to stabilize
  delay(500);
}

//////////////////////////////////////////////////////////////////////////////////////

void loop() {    /****** LOOP: RUNS CONSTANTLY ******/

  double internalCentigrade =   thermocouple.readInternal();

  double centigrade = thermocouple.readCelsius();

  if (isnan(centigrade)) { // Error thermocouple
    // If there is an error with the TC, temperature will be < 0

    Serial.println("Something wrong with thermocouple!");

    turnOffRGB();

    // noflash Blue
    for (int noFlash = 0; noFlash < 4; noFlash++)
    {
      analogWrite(bluePin, 255);      // sets the Blue LED on
      delay(500);
    } // for
  }// Error thermocouple
  else {   // Not a  Error thermocouple

    //centigrade=centigrade+internalCentigrade;

    Serial.print("C = ");
    Serial.print(centigrade);
    Serial.write(176);  // The degrees symbol

    //  Green= Cool safe
    if (centigrade <= 35)
    {
      turnOffRGB();

      Serial.println(" Cool Green");

      //  noflash Green
      for (int noFlash = 0; noFlash < 4; noFlash++)
      {
        analogWrite(greenPin, 255);    // sets the Green LED on
        delay(500);
      }//for
    }//  Green= Cool safe

    // Yellow = Warm Take some care
    // NOTE :  Yellow = red + some green, not total green
    if ((centigrade > 35) && (centigrade <= 45))
    {
      turnOffRGB();

      Serial.println(" Medium Heat Yellow");

      // noflash Yellow. Red and Green mixed NOTE :  Yellow = red + some green, not total green
      for (int noFlash = 0; noFlash < 4; noFlash++)
      {
        // noflash Yellow. Red and Green mixed NOTE :  Yellow = red + some green, not total green
        analogWrite(redPin, 255);      // sets the Red LED on
        analogWrite(greenPin, 65);    // sets the Green LED partly  Yellow = red + some green, not total green
        delay(500);
      }//for
    }// Yellow = Warm Take some care

    // Red = Hot Danger do not touch
    if ((centigrade > 45) && (centigrade <= 50))
    {
      turnOffRGB();

      Serial.println(" Hot!!! Red");

      // noflash Red
      for (int noFlash = 0; noFlash < 4; noFlash++)
      {
        analogWrite(redPin, 255);      // sets the Red LED on
        delay(500);
      }//for
    }// Red = Hot Danger do not touch

    // Red Flashing = Very Hot Danger do not touch
    if ((centigrade > 50) && (centigrade <= 170))
    {
      turnOffRGB();

      Serial.println(" Very HOT!! RED Flashing");

      // flash Red
      for (int flash = 0; flash < 4; flash++)
      {
        analogWrite(redPin, 255);    // sets the Red LED on
        delay(50);
        analogWrite(redPin, 0);      // sets the Red LED off
      }//for
    }// Red Flashing = Very Hot Danger do not touch

    // More than 170°C  White Flashing : TOO HOT!!!! OVER Temperature ERROR!!!
    // Red + Green + Blue LED
    if (centigrade > 170)
    {
      turnOffRGB();

      Serial.println(" TOO HOT!!!! OVER Temperature ERROR!!!");

      // White Flashing = Red/Green/Blue
      for (int flash = 0; flash < 4; flash++)
      {
        analogWrite(redPin, 255);    // sets the Red LED on
        analogWrite(greenPin, 255);  // sets the Green LED on
        analogWrite(bluePin, 255);   // sets the Blue LED on

        delay(50);

        turnOffRGB();

        delay(50);
      }//for
    }// More than 170°C  White Quick Flashing : TOO HOT!!!! OVER Temperature ERROR!!!
  }// Not an Error thermocouple

  delay(500);

} // --(end main loop )---

//////////////////////////////////////////////////////////////////////////////////////

void turnOffRGB()
{
  analogWrite(redPin, 0);      // sets the Red LED off
  analogWrite(greenPin, 0);    // sets the Green LED off
  analogWrite(bluePin, 0);     // sets the Blue LED off
}


